%DRAW   Draw point feature.
%   DRAW(P,IDS,COLOR) draws the point feature P into the
%   current figure with color COLOR. Enable and disable
%   display of feature identifiers with the flag IDS
%   being 1 or 0. COLOR is a [r g b]-vector or a Matlab
%   color string such as 'r' or 'g'.
% 
%   H = DRAW(...) returns a column vector of handles to
%   the line objects of the drawing.
%
%   See also POINTFEATURE.

% v.1.0, Nov. 2003, Kai Arras, CAS-KTH


function h = draw(p,ids,color);

% Constants
MSIZE = 9;             % marker size of point feature
FSIZE = 0.05;           % font scale in [m]
FOFFS = 0.03;          % font offset in [m]

% Draw label
if ids,
  h1 = drawlabel([p.x; 0],num2str(get(p,'id')),FSIZE,FOFFS,color);
else
  h1 = [];
end;

% Draw point feature
h2 = plot(p.x(1),p.x(2),'+',p.x(1),p.x(2),'d','MarkerSize',MSIZE,'Color',color);
h = cat(1,h1,h2);