function [aL,aR]=getAngularDispl(newPos,oldPos, rl,rr,b)
%
% newPos and oldPos are [1x3] arrays representing robotpose [x, y, theta],
% aL is the angular displacement of left wheel between newPos and oldPos,
% aR is the angular displacement of right wheel between newPos and oldPos
% rl=radius of left wheel, rr=radius of right wheel and b=width between
% wheels.
% All angles in rad.
aL=0;
aR=0;

x1=newPos(1);
y1=newPos(2);
theta1=newPos(3);

x2=oldPos(1);
y2=oldPos(2);
theta2=oldPos(3);

dx=x2-x1;
dy=y2-y1;

dist=sqrt(dx^2 + dy^2);

% angular displacement from distance
aL=aL + dist/rl;
aR=aR + dist/rr;

% angular displacement from rotations
deltaTheta=(theta2 - theta1);
if deltaTheta~=0,
    if deltaTheta<0 && deltaTheta>=-pi,
        % rotation clockwise
        aL=aL + (deltaTheta*b/2)/rl;
        aR=aR - (deltaTheta*b/2)/rr;
    elseif deltaTheta>pi,
        % rotation clockwise
        deltaTheta=deltaTheta-2*pi;
        aL=aL - (deltaTheta*b/2)/rl;
        aR=aR + (deltaTheta*b/2)/rr;
        
    elseif deltaTheta<-pi,
        % rotation counterclockwise
        deltaTheta=deltaTheta+2*pi;
        aL=aL - (deltaTheta*b/2)/rl;
        aR=aR + (deltaTheta*b/2)/rr;
    elseif deltaTheta>0 && deltaTheta<=pi,
        % rotation counterclockwise
        aL=aL - (deltaTheta*b/2)/rl;
        aR=aR + (deltaTheta*b/2)/rr;
    
        
    end
else
    % no rotation
end
%aL=aL*180/pi;        
%aR=aR*180/pi;
